@@ -35,6 +35,7 @@ static void* xcalloc(size_t size)
 /*  I/O routines (speak, pspeak, rspeak, sspeak, get_input, yes) */
 
 static void vspeak(const char* msg, bool blank, va_list ap)
+/* Engine for various speak functions */
 {
     // Do nothing if we got a null pointer.
     if (msg == NULL)
@@ -122,6 +123,7 @@ static void vspeak(const char* msg, bool blank, va_list ap)
 }
 
 void speak(const char* msg, ...)
+/* speak a specified string */
 {
     va_list ap;
     va_start(ap, msg);
@@ -130,6 +132,7 @@ void speak(const char* msg, ...)
 }
 
 void sspeak(const int msg, ...)
+/* Speak a message from the arbitrary-messages list */
 {
     va_list ap;
     va_start(ap, msg);
@@ -280,12 +283,10 @@ bool silent_yes_or_no(void)
 
         free(firstword);
 
-        if (yes == 0 ||
-            y == 0) {
+        if (yes == 0 || y == 0) {
             outcome = true;
             break;
-        } else if (no == 0 ||
-                   n == 0) {
+        } else if (no == 0 || n == 0) {
             outcome = false;
             break;
         } else
@@ -566,7 +567,6 @@ void clear_command(command_t *cmd)
     cmd->state = EMPTY;
 }
 
-
 void juggle(obj_t object)
 /*  Juggle an object by picking it up and putting it down again, the purpose
  *  being to get the object to the front of the chain of things at its loc. */
@@ -633,7 +633,7 @@ void carry(obj_t object, loc_t where)
 
 void drop(obj_t object, loc_t where)
 /*  Place an object at a given loc, prefixing it onto the game.atloc list.  Decr
- *  game.holdng if the object was being toted. */
+ *  game.holdng if the object was being toted. No state change on the object. */
 {
     if (object > NOBJECTS)
         game.fixed[object - NOBJECTS] = where;
@@ -728,8 +728,6 @@ void bug(enum bugtype num, const char *error_string)
 }
 // LCOV_EXCL_STOP
 
-/* end */
-
 void state_change(obj_t obj, int state)
 /* Object must have a change-message list for this to be useful; only some do */
 {
